@@ -9,13 +9,17 @@
 #  An AromaPlatform provides methods for a given platform, e.g.
 #  Affymetrix, Agilent, Illumina.
 # }
-# 
+#
 # @synopsis
 #
 # \arguments{
 #   \item{...}{Not used.}
 # }
 #
+# \examples{\dontrun{
+#  @include "../incl/AromaPlatform.Rex"
+# }}
+#
 # \section{Methods}{
 #  @allmethods "public"
 # }
@@ -23,22 +27,32 @@
 # @author
 #*/###########################################################################
 setConstructorS3("AromaPlatform", function(...) {
-  extend(Object(), "AromaPlatform");
+  extend(Object(), "AromaPlatform")
 })
 
 
+setMethodS3("as.character", "AromaPlatform", function(x, ...) {
+  s <- sprintf("%s:", class(x)[1L])
+  s <- c(s, sprintf("Platform: %s", getName(x)))
+  GenericSummary(s)
+}, protected=TRUE)
+
+
 setMethodS3("byName", "AromaPlatform", function(static, name, ...) {
-  className <- sprintf("%sPlatform", capitalize(name));
-  clazz <- Class$forName(className);
-  newInstance(clazz);
-}, static=TRUE);
+  className <- sprintf("%sPlatform", capitalize(name))
+  clazz <- Class$forName(className)
+  newInstance(clazz)
+}, static=TRUE)
 
 
 setMethodS3("getName", "AromaPlatform", function(this, ...) {
-  name <- class(this)[1];
-  name <- name[1];
-  name <- gsub("Platform", "", name);
-  name;
+  name <- class(this)[1L]
+  name <- gsub("Platform", "", name)
+  name
+})
+
+setMethodS3("equals", "AromaPlatform", function(this, other, ...) {
+  (getName(this) == getName(other))
 })
 
 setMethodS3("findUnitNamesFile", "AromaPlatform", abstract=TRUE, protected=TRUE)
@@ -51,7 +65,7 @@ setMethodS3("getUnitTypesFile", "AromaPlatform", abstract=TRUE)
 
 
 setMethodS3("getAromaUgpFile", "AromaPlatform", function(static, ...) {
-  AromaUgpFile$byName(...);
+  AromaUgpFile$byName(...)
 }, static=TRUE)
 
 
@@ -59,6 +73,8 @@ setMethodS3("getAromaUgpFile", "AromaPlatform", function(static, ...) {
 
 ############################################################################
 # HISTORY:
+# 2014-06-24
+# o Added equals() and as.character() for AromaPlatform.
 # 2009-07-08
 # o Added getUnitTypesFile() for AromaPlatform.
 # 2008-05-18
