@@ -170,7 +170,7 @@ setMethodS3("plot", "CopyNumberSegmentationModel", function(x, xlim=NULL, ..., p
         xlim <- c(0, widthMb);
       }
 
-      verbose && enter(verbose, sprintf("Plotting %s for chromosome %02d [%.2fMB]", arrayName, chromosome, widthMb));
+      verbose && enter(verbose, sprintf("Plotting %s for chromosome %02d [%.2f Mbp]", arrayName, chromosome, widthMb));
 
       for (zz in seq_along(zooms)) {
         zoom <- zooms[zz];
@@ -188,10 +188,10 @@ setMethodS3("plot", "CopyNumberSegmentationModel", function(x, xlim=NULL, ..., p
           }
         }
 
-        # Calculate MBs per ticks
+        # Calculate Mbps per ticks
         ticksBy <- 10^ceiling(log10(pixelsPerTick / (zoom * pixelsPerMb)));
 
-        # Calculate width in pixels from MBs
+        # Calculate width in pixels from Mbps
         width <- round(zoom * widthMb * pixelsPerMb + sum(xmargin));
 
         # Plot to PNG file
