@@ -413,7 +413,7 @@ setMethodS3("pointsSequence", "ProbePositionEffects", function(fit, seq, col=NUL
 
   # Argument 'seq':
   seq <- paste(seq, collapse="");
-  seq <- Arguments$getCharacter(seq, nchar=rep(nrow(rho),2), length=c(1,1));
+  seq <- Arguments$getCharacter(seq, nchar=rep(nrow(rho), times=2), length=c(1,1));
 
   if (is.null(col)) {
     col <- seq_len(ncol(rho));
@@ -438,7 +438,7 @@ setMethodS3("textSequence", "ProbePositionEffects", function(fit, seq, labels=NU
 
   # Argument 'seq':
   seq <- paste(seq, collapse="");
-  seq <- Arguments$getCharacter(seq, nchar=rep(nrow(rho),2), length=c(1,1));
+  seq <- Arguments$getCharacter(seq, nchar=rep(nrow(rho), times=2), length=c(1,1));
 
   if (is.null(labels)) {
     labels <- colnames(rho);
@@ -469,7 +469,7 @@ setMethodS3("barSequence", "ProbePositionEffects", function(fit, seq, col=NULL,
 
   # Argument 'seq':
   seq <- paste(seq, collapse="");
-  seq <- Arguments$getCharacter(seq, nchar=rep(nrow(rho),2), length=c(1,1));
+  seq <- Arguments$getCharacter(seq, nchar=rep(nrow(rho), times=2), length=c(1,1));
 
   if (is.null(col)) {
     col <- seq_len(ncol(rho));
