@@ -24,7 +24,7 @@ setConstructorS3("RawAlleleBFractions", function(...) {
 })
 
 setMethodS3("plot", "RawAlleleBFractions", function(x, ..., ylim=c(0,1)+c(-0.2,0.2), ylab="Allele B fraction") {
-  NextMethod("plot", x, ..., ylim=ylim, ylab=ylab);
+  NextMethod("plot", ylim=ylim, ylab=ylab);
 })
 
 setMethodS3("extractRawAlleleBFractions", "default", abstract=TRUE);
